from envisage.plugins.python_shell.i_python_shell import IPythonShell
from .i_namespace_view import INamespaceView
